//-*-C++-*-
/*
**************************************************************************
                                 description
                             --------------------
    copyright            : (C) 2002 by Luis Carvalho
    email                : lpassos@mail.telepac.pt
**************************************************************************

**************************************************************************
*                                                                        *
*  This program is free software; you can redistribute it and/or modify  *
*  it under the terms of the GNU General Public License as published by  *
*  the Free Software Foundation; either version 2 of the License, or     *
*  (at your option) any later version.                                   *
*                                                                        *
**************************************************************************/

#ifndef PMLIBRARYOBJECTBROWSER_H
#define PMLIBRARYOBJECTBROWSER_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <qwidget.h>
#include <qstringlist.h>
#include <kfileiconview.h>

class KConfig;
class QComboBox;
class KDirOperator;
class PMPart;

/** 
 * This class provides a non-modal dialog to browse the available libraries.
 */
class PMLibraryObjectBrowser: public QWidget
{
   Q_OBJECT
public:
   static void saveConfig( KConfig* cfg );
   static void restoreConfig( KConfig* cfg );
   static QSize s_size;

   /** 
    * Get the library paths 
    */
   static QStringList libraryPaths( ) { return s_libraryPaths; }
   /** 
    * Set the library paths 
    */
   static void setLibraryPaths( const QStringList& l );
   /** 
    * Creates and shows the Library Browser 
    */
   static void showBrowser( );

private slots:
   void resizeEvent( QResizeEvent* ev );
   void slotPathSelected( const QString& str );
   void slotDragStart( );

private:

   PMLibraryObjectBrowser( QWidget *parent, const char* name = NULL );
   QComboBox*    m_pLibraryComboBox;
   KDirOperator* m_pBrowser;
   PMPart*       m_pPart;

   static QStringList s_libraryPaths;
   static PMLibraryObjectBrowser* s_pLibraryBrowser;
};

/**
 * This class is used internally by @ref PMLibraryObjectBrowser.
 * Basically it's a @ref KFileIconView with specialized drag'n'drop.
 * When KFileIconView provides drag'n'drop it will be replaced. 
 */
class PMFileView: public KFileIconView
{
   Q_OBJECT
public:
   PMFileView( QWidget* parent, const char* name );
protected:
   virtual QDragObject* dragObject( ) const;
   virtual void startDrag( );
protected slots:
   virtual void mousePressEvent( QMouseEvent* e );
   virtual void mouseReleaseEvent( QMouseEvent* e );
   virtual void mouseMoveEvent( QMouseEvent* e );
signals:
   void dragStart( );
private:
   bool         m_pressed;
   QPoint       m_pressedPos;
   QDragObject* m_dragObject;
};

#endif
