/*
**************************************************************************
                                 description
                             --------------------
    copyright            : (C) 2002 by Luis Carvalho
    email                : lpassos@mail.telepac.pt
**************************************************************************

**************************************************************************
*                                                                        *
*  This program is free software; you can redistribute it and/or modify  *
*  it under the terms of the GNU General Public License as published by  *
*  the Free Software Foundation; either version 2 of the License, or     *
*  (at your option) any later version.                                   *
*                                                                        *
**************************************************************************/


#include "pmlibraryobjectedit.h"

#include <qlistbox.h>
#include <qpushbutton.h>
#include <qcheckbox.h>
#include <qlineedit.h>
#include <qtextedit.h>
#include <qtabwidget.h>
#include <qvbox.h>
#include <qlayout.h>
#include <qlabel.h>
#include <qcombobox.h>
#include <qgroupbox.h>
#include <qimage.h>

#include <klocale.h>
#include <kconfig.h>
#include <kmessagebox.h>
#include <kfiledialog.h>

#include "pmlineedits.h"
#include "pmdialogeditbase.h"
#include "pmlibraryobject.h"

QSize PMLibraryObjectEdit::s_size = QSize( 600, 400 );

PMLibraryObjectEdit::PMLibraryObjectEdit( PMLibraryObject* obj, QWidget* parent, const char* name )
      : KDialogBase( parent, name, true, i18n( "Save Library Object" ),
                     Ok | Cancel, Ok )
{
   m_pObject = obj;

   resize( s_size );
   QWidget* page = new QWidget( this );
   setMainWidget( page );
   QVBoxLayout* vl = new QVBoxLayout( page, KDialog::spacingHint( ) );

   QGridLayout* grid = new QGridLayout( vl, 4, 2 );
   QLabel* lbl = new QLabel( i18n( "Name: " ), page );
   m_pNameEdit = new QLineEdit( page );
   grid->addWidget( lbl, 0, 0 );
   grid->addWidget( m_pNameEdit, 0, 1 );

   lbl = new QLabel( i18n( "Type: " ), page );
   m_pTypeEdit = new QLineEdit( page );
   grid->addWidget( lbl, 1, 0 );
   grid->addWidget( m_pTypeEdit, 1, 1 );

   lbl = new QLabel( i18n( "Description: " ), page );
   m_pDescriptionEdit = new QTextEdit( page );
   m_pDescriptionEdit->setMaximumHeight( 120 );
   grid->addWidget( lbl, 2, 0 );
   grid->addMultiCellWidget( m_pDescriptionEdit, 2, 3, 1, 1 );
   grid->setRowStretch( 3, 1 );

   QHBoxLayout* hl = new QHBoxLayout( vl );
   QGroupBox* frame = new QGroupBox( 1, Qt::Vertical, i18n( "Keywords" ), page );
   QWidget* insideFrame = new QWidget( frame );
   hl->addWidget( frame );
   grid = new QGridLayout( insideFrame, 3, 2, KDialog::spacingHint( ) );
   m_pKeywordsList = new QListBox( insideFrame );
   m_pKeywordAdd = new QPushButton( i18n( "Add" ), insideFrame );
   m_pKeywordRemove = new QPushButton( i18n( "Remove" ), insideFrame );
   grid->addMultiCellWidget( m_pKeywordsList, 0, 2, 0, 0 );
   grid->addWidget( m_pKeywordAdd, 0, 1 );
   grid->addWidget( m_pKeywordRemove, 1, 1 );
   m_pKeywordEdit = new QLineEdit( insideFrame );
   grid->addWidget( m_pKeywordEdit, 3, 0 );
   grid->setRowStretch( 2, 1 );

   frame = new QGroupBox( 1, Qt::Vertical, i18n( "Preview" ), page );
   m_pPreviewEdit = new QPushButton( frame );
   m_pPreviewEdit->setMinimumSize( PMDialogEditBase::previewSize( ) , PMDialogEditBase::previewSize( ) );
   m_pPreviewEdit->setMaximumSize( PMDialogEditBase::previewSize( ) , PMDialogEditBase::previewSize( ) );
   hl->addWidget( frame );

   connect( m_pNameEdit, SIGNAL( textChanged( const QString& ) ), SLOT( slotEditsChanged( const QString& ) ) );
   connect( m_pTypeEdit, SIGNAL( textChanged( const QString& ) ), SLOT( slotEditsChanged( const QString& ) ) );
   connect( m_pDescriptionEdit, SIGNAL( textChanged( ) ), SLOT( slotDescriptionChanged( ) ) );
   connect( m_pKeywordAdd, SIGNAL( pressed( ) ), SLOT( slotAddKeywordPressed( ) ) );
   connect( m_pKeywordRemove, SIGNAL( pressed( ) ), SLOT( slotRemoveKeywordPressed( ) ) );
   connect( m_pPreviewEdit, SIGNAL( pressed( ) ), SLOT( slotPreviewPressed( ) ) );

   enableButtonOK( false );
}

void PMLibraryObjectEdit::slotEditsChanged( const QString& /*str*/ )
{
   enableButtonOK( true );
}

void PMLibraryObjectEdit::slotDescriptionChanged( )
{
   enableButtonOK( true );
}

void PMLibraryObjectEdit::slotAddKeywordPressed( )
{
   // Keywords are always in lower case
   QString str = m_pKeywordEdit->text( ).lower( );

   if( !str.isEmpty() )
   {
      // Check if this keyword already exists
      // We start from the end to avoid calculating count() several times
      for( int i = m_pKeywordsList->count( ); i > -1; i-- )
      {
         if( str == m_pKeywordsList->text( i ) )
            return;
      }

      // If we reach this point it's ok to insert the item.
      m_pKeywordsList->insertItem( str, -1 );
      enableButtonOK( true );
   }
}

void PMLibraryObjectEdit::slotRemoveKeywordPressed( )
{
   if( m_pKeywordsList->currentItem( ) != -1 )
   {
      m_pKeywordsList->removeItem( m_pKeywordsList->currentItem( ) );
      enableButtonOK( true );
   }
}

void PMLibraryObjectEdit::slotPreviewPressed( )
{
   KFileDialog dlg( QString::null, "", NULL, "", false );
   
   dlg.setFilter( "image/jpeg image/gif image/tiff image/png image/x-bmp" );
   if( dlg.exec( ) == QDialog::Accepted )
   {
      QImage a( dlg.selectedFile( ) );
      QPixmap pix;

      pix.convertFromImage( a.smoothScale( PMDialogEditBase::previewSize( ),
                                           PMDialogEditBase::previewSize( ) ) );
      m_pPreviewEdit->setPixmap( pix );
      enableButtonOK( true );
   }
}

void PMLibraryObjectEdit::saveConfig( KConfig* cfg )
{
   cfg->setGroup( "Appearance" );
   cfg->writeEntry( "LibraryObjectEditSize", s_size );
}

void PMLibraryObjectEdit::restoreConfig( KConfig* cfg )
{
   cfg->setGroup( "Appearance" );

   QSize defaultSize( 300, 200 );
   s_size = cfg->readSizeEntry( "LibraryObjectEditSize", &defaultSize );
}

void PMLibraryObjectEdit::resizeEvent( QResizeEvent* ev )
{
   s_size = ev->size( );
}

void PMLibraryObjectEdit::slotOk( )
{
   m_pObject->setName( m_pNameEdit->text( ) );
   m_pObject->setType( m_pTypeEdit->text( ) );
   m_pObject->setDescription( m_pDescriptionEdit->text( ) );
   if( m_pPreviewEdit->pixmap( ) )
      m_pObject->setPreview( m_pPreviewEdit->pixmap( )->convertToImage( ) );

   m_pObject->clearKeywords( );
   for( int i = m_pKeywordsList->count( ); i > -1; i-- )
      m_pObject->addKeyword( m_pKeywordsList->text( i ) );

   accept( );
}

#include "pmlibraryobjectedit.moc"
